/* eslint-disable */
import {
    Http,
    Metadata,
} from '@zeedhi/core';
import {
    DialogService, AlertService, FileInput, Form,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Utilities {
    public static alertMessage(message: string, type: string) {
        AlertService.show({
            name: 'basic-alert',
            text: message,
            top: true,
            left: false,
            timeout: 3000,
            color: type,
        });
    }

    public static showErrorMessage(error: any) {
        console.error(error);
        let msg = '';
        if (error.response && error.response.data && error.response.data.error) {
            msg = error.response.data.error;
        } else {
            msg = error;
        }
        if (!msg) {
            msg = 'Ocorreu um erro inesperado. Por favor, entre em contato com o suporte.';
        }

        if (msg.includes("ORA-02292")) {
            msg = "Exclusão não permitida! O registro possui registros filhos.";
        }

        DialogService.show({
            name: 'error_dialog',
            type: 'error',
            title: 'Erro',
            text: msg,
        });
    }

    public static async salvarDados(rota: any, parametros: any) {
        await Http.post(rota, parametros).then(() => {
            this.showSuccessMessage();
        }).catch((error: any) => {
            this.showErrorMessage(error);
        });
    }

    public static showSuccessMessage() {
        AlertService.show({
            name: 'basic-alert',
            text: 'Processo realizado com sucesso!',
            top: true,
            left: false,
            color: 'success',
            timeout: 2000,
            buttonsSlot: [
                {
                    name: 'undo-button',
                    component: 'ZdButton',
                    icon: true,
                    right: true,
                    iconName: 'close',
                    color: 'white',
                    events: {
                        click: () => { AlertService.hide(); },
                    },
                },
            ],
        });
    }

    public static async buildArrayToUpload(nomeComponente: string) {
        const file = Metadata.getInstance<FileInput>(nomeComponente).value;
        if (file) {
            const base64file = await this.toBase64(file);
            return [{
                b64File: base64file,
                lastModified: file.lastModified,
                name: file.name,
                size: file.size,
                type: file.type,
                webkitRelativePath: file.webkitRelativePath,
            }];
        }
        return [];
    }

    /* public static async buildArrayToUploadPromise(nomeComponente: string) {
        const file = Metadata.getInstance<FileInput>(nomeComponente).value;
        return new Promise((resolve, reject) => {
            if (file) {
                this.toBase64(file).then((base64file) => {
                    resolve([{
                        b64File: base64file,
                        lastModified: file.lastModified,
                        name: file.name,
                        size: file.size,
                        type: file.type,
                        webkitRelativePath: file.webkitRelativePath,
                    }]);
                }).catch((error) => {
                    reject(error);
                });
            }
            else {
                resolve([]);
            }
        });
    }; */

    public static async toBase64(file: any) {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.readAsDataURL(file);
            reader.onload = () => resolve(reader.result);
            reader.onerror = (error) => reject(error);
        });
    }

    public static showConfirmDeleteMessage(event: any, functionConfirm: string) {
        event.preventDefault();
        functionConfirm = '{{' + functionConfirm + '}}';
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'button-no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: {
                        click: () => DialogService.hide(),
                    },
                    outline: true,
                },
                {
                    name: 'button-yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: functionConfirm
                    },
                },
            ],
        });
    }

    public static getOperadorLogado() {
        return Http.post('/getOperadorLogado', {}).then((response) => {
            return new Promise((resolve, reject) => {
                resolve(response.data.dataset.retorno.cdoperador);
            });
        });
    }

    public static validateForm(form : Form) {
        if (form.validate()) {
            return true;
        }
        this.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        return false;
    }

    public static validateGrid(grid : TekGrid) {
        if (grid.isGridValid()) {
            return true;
        }
        this.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        return false;
    }

    public static async timeout(time: number) {
        return new Promise((resolve) => setTimeout(resolve, time));
    }

    public static async doAsync(callBack: Function, time: number) {
        return new Promise<void>((resolve) => {
            this.timeout(time).then(() => {
                callBack();
                resolve();
            });
        });
    }
}
